# SaladCloudSdk Python SDK 0.9.0-alpha.11

Welcome to the SaladCloudSdk SDK documentation. This guide will help you get started with integrating and using the SaladCloudSdk SDK in your project.

[![This SDK was generated by liblab](https://public-liblab-readme-assets.s3.us-east-1.amazonaws.com/built-by-liblab-icon.svg)](https://liblab.com/?utm_source=readme)

## Versions

- API version: `0.9.0-alpha.11`
- SDK version: `0.9.0-alpha.11`

## About the API

The SaladCloud REST API. Please refer to the [SaladCloud API Documentation](https://docs.salad.com/api-reference) for more details.

## Table of Contents

- [Setup & Configuration](#setup--configuration)
  - [Supported Language Versions](#supported-language-versions)
  - [Installation](#installation)
- [Authentication](#authentication)
  - [API Key Authentication](#api-key-authentication)
- [Setting a Custom Timeout](#setting-a-custom-timeout)
- [Sample Usage](#sample-usage)
- [Async Usage](#async-usage)
- [Services](#services)
- [Models](#models)
- [License](#license)

## Setup & Configuration

### Supported Language Versions

This SDK is compatible with the following versions: `Python >= 3.7`

### Installation

To get started with the SDK, we recommend installing using `pip`:

```bash
pip install salad-cloud-sdk
```

## Authentication

### API Key Authentication

The SaladCloudSdk API uses API keys as a form of authentication. An API key is a unique identifier used to authenticate a user, developer, or a program that is calling the API.

#### Setting the API key

When you initialize the SDK, you can set the API key as follows:

```py
SaladCloudSdk(
    api_key="YOUR_API_KEY",
    api_key_header="YOUR_API_KEY_HEADER",
    timeout=10000
)
```

If you need to set or update the API key after initializing the SDK, you can use:

```py
sdk.set_api_key("YOUR_API_KEY", "YOUR_API_KEY_HEADER")
```

## Setting a Custom Timeout

You can set a custom timeout for the SDK's HTTP requests as follows:

```py
from salad_cloud_sdk import SaladCloudSdk

sdk = SaladCloudSdk(timeout=10000)
```

# Sample Usage

Below is a comprehensive example demonstrating how to authenticate and call a simple endpoint:

```py
from salad_cloud_sdk import SaladCloudSdk

sdk = SaladCloudSdk(
    api_key="YOUR_API_KEY",
    api_key_header="YOUR_API_KEY_HEADER",
    timeout=10000
)

result = sdk.quotas.get_quotas(organization_name="acme-corp")

print(result)

```

# Async Usage

The SDK includes an Async Client for making asynchronous API requests. This is useful for applications that need non-blocking operations, like web servers or apps with a graphical user interface.

```py
import asyncio
from salad_cloud_sdk import SaladCloudSdkAsync

sdk = SaladCloudSdkAsync(
    api_key="YOUR_API_KEY",
    api_key_header="YOUR_API_KEY_HEADER",
    timeout=10000
)


async def main():
  result = await sdk.quotas.get_quotas(organization_name="acme-corp")
  print(result)

asyncio.run(main())
```

## Services

The SDK provides various services to interact with the API.

<details> 
<summary>Below is a list of all available services with links to their detailed documentation:</summary>

| Name                                                                             |
| :------------------------------------------------------------------------------- |
| [ContainerGroupsService](documentation/services/ContainerGroupsService.md)       |
| [WorkloadErrorsService](documentation/services/WorkloadErrorsService.md)         |
| [SystemLogsService](documentation/services/SystemLogsService.md)                 |
| [QueuesService](documentation/services/QueuesService.md)                         |
| [QuotasService](documentation/services/QuotasService.md)                         |
| [InferenceEndpointsService](documentation/services/InferenceEndpointsService.md) |
| [OrganizationDataService](documentation/services/OrganizationDataService.md)     |
| [WebhookSecretKeyService](documentation/services/WebhookSecretKeyService.md)     |

</details>

## Models

The SDK includes several models that represent the data structures used in API requests and responses. These models help in organizing and managing the data efficiently.

<details> 
<summary>Below is a list of all available models with links to their detailed documentation:</summary>

| Name                                                                                                         | Description                                                                                                                                                                                                                                                                                                                                                           |
| :----------------------------------------------------------------------------------------------------------- | :-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [ContainerGroupCollection](documentation/models/ContainerGroupCollection.md)                                 | A paginated collection of container groups that provides a structured way to access multiple container group resources in a single response.                                                                                                                                                                                                                          |
| [ContainerGroupCreationRequest](documentation/models/ContainerGroupCreationRequest.md)                       | Represents a request to create a container group, which manages a collection of container instances with shared configuration and scaling policies                                                                                                                                                                                                                    |
| [ContainerGroup](documentation/models/ContainerGroup.md)                                                     | A container group definition that represents a scalable set of identical containers running as a distributed service                                                                                                                                                                                                                                                  |
| [ContainerGroupPatch](documentation/models/ContainerGroupPatch.md)                                           | Represents a request to update a container group                                                                                                                                                                                                                                                                                                                      |
| [ContainerGroupInstanceCollection](documentation/models/ContainerGroupInstanceCollection.md)                 | A collection of container group instances returned as part of a paginated response or batch operation result.                                                                                                                                                                                                                                                         |
| [ContainerGroupInstance](documentation/models/ContainerGroupInstance.md)                                     | A Container Group Instance represents a running instance of a container group on a specific machine. It provides information about the execution state, readiness, and version of the deployed container group.                                                                                                                                                       |
| [ContainerGroupInstancePatch](documentation/models/ContainerGroupInstancePatch.md)                           | Represents a request to update a container group instance                                                                                                                                                                                                                                                                                                             |
| [WorkloadErrorList](documentation/models/WorkloadErrorList.md)                                               | Represents a list of workload errors                                                                                                                                                                                                                                                                                                                                  |
| [SystemLogList](documentation/models/SystemLogList.md)                                                       | Represents a list of system logs                                                                                                                                                                                                                                                                                                                                      |
| [QueueCollection](documentation/models/QueueCollection.md)                                                   | Represents a Queue Collection                                                                                                                                                                                                                                                                                                                                         |
| [QueuePrototype](documentation/models/QueuePrototype.md)                                                     | Represents a request to create a new queue.                                                                                                                                                                                                                                                                                                                           |
| [Queue](documentation/models/Queue.md)                                                                       | Represents a queue.                                                                                                                                                                                                                                                                                                                                                   |
| [QueuePatch](documentation/models/QueuePatch.md)                                                             | Represents a request to update an existing queue.                                                                                                                                                                                                                                                                                                                     |
| [QueueJobCollection](documentation/models/QueueJobCollection.md)                                             | Represents a Queue Job Collection                                                                                                                                                                                                                                                                                                                                     |
| [QueueJobPrototype](documentation/models/QueueJobPrototype.md)                                               | Represents a request to create a queue job                                                                                                                                                                                                                                                                                                                            |
| [QueueJob](documentation/models/QueueJob.md)                                                                 | Represents a queue job                                                                                                                                                                                                                                                                                                                                                |
| [Quotas](documentation/models/Quotas.md)                                                                     | Represents the organization quotas                                                                                                                                                                                                                                                                                                                                    |
| [InferenceEndpointCollection](documentation/models/InferenceEndpointCollection.md)                           | Represents a page from the collection of inference endpoints.                                                                                                                                                                                                                                                                                                         |
| [InferenceEndpoint](documentation/models/InferenceEndpoint.md)                                               | Represents an inference endpoint                                                                                                                                                                                                                                                                                                                                      |
| [InferenceEndpointJobCollection](documentation/models/InferenceEndpointJobCollection.md)                     | Represents a collection of inference endpoint jobs                                                                                                                                                                                                                                                                                                                    |
| [InferenceEndpointJobPrototype](documentation/models/InferenceEndpointJobPrototype.md)                       | Represents a request to create a inference endpoint job                                                                                                                                                                                                                                                                                                               |
| [InferenceEndpointJob](documentation/models/InferenceEndpointJob.md)                                         | Represents a inference endpoint job                                                                                                                                                                                                                                                                                                                                   |
| [GpuClassesList](documentation/models/GpuClassesList.md)                                                     | Represents a list of GPU classes                                                                                                                                                                                                                                                                                                                                      |
| [WebhookSecretKey](documentation/models/WebhookSecretKey.md)                                                 | Represents a webhook secret key                                                                                                                                                                                                                                                                                                                                       |
| [Container](documentation/models/Container.md)                                                               | Represents a container with its configuration and resource requirements.                                                                                                                                                                                                                                                                                              |
| [CountryCode](documentation/models/CountryCode.md)                                                           | ISO 3166-1 alpha-2 country codes                                                                                                                                                                                                                                                                                                                                      |
| [ContainerGroupState](documentation/models/ContainerGroupState.md)                                           | Represents the operational state of a container group during its lifecycle, including timing information, status, and instance distribution metrics. This state captures the current execution status, start and finish times, and provides visibility into the operational health across instances.                                                                  |
| [ContainerGroupLivenessProbe](documentation/models/ContainerGroupLivenessProbe.md)                           | Defines a liveness probe for container groups that determines when to restart a container if it becomes unhealthy                                                                                                                                                                                                                                                     |
| [ContainerGroupNetworkingConfiguration](documentation/models/ContainerGroupNetworkingConfiguration.md)       | Network configuration for container groups that defines connectivity, routing, and access control settings                                                                                                                                                                                                                                                            |
| [ContainerGroupPriority](documentation/models/ContainerGroupPriority.md)                                     | Specifies the priority level for container group execution, which determines resource allocation and scheduling precedence.                                                                                                                                                                                                                                           |
| [QueueBasedAutoscalerConfiguration](documentation/models/QueueBasedAutoscalerConfiguration.md)               | Defines configuration for automatically scaling container instances based on queue length. The autoscaler monitors a queue and adjusts the number of running replicas to maintain the desired queue length.                                                                                                                                                           |
| [ContainerGroupQueueConnection](documentation/models/ContainerGroupQueueConnection.md)                       | Configuration for connecting a container group to a message queue system, enabling asynchronous communication between services.                                                                                                                                                                                                                                       |
| [ContainerGroupReadinessProbe](documentation/models/ContainerGroupReadinessProbe.md)                         | Defines how to check if a container is ready to serve traffic. The readiness probe determines whether the container's application is ready to accept traffic. If the readiness probe fails, the container is considered not ready and traffic will not be sent to it.                                                                                                 |
| [ContainerRestartPolicy](documentation/models/ContainerRestartPolicy.md)                                     | Specifies the policy for restarting containers when they exit or fail.                                                                                                                                                                                                                                                                                                |
| [ContainerGroupStartupProbe](documentation/models/ContainerGroupStartupProbe.md)                             | Defines a probe that checks if a container application has started successfully. Startup probes help prevent applications from being prematurely marked as unhealthy during initialization. The probe can use HTTP requests, TCP connections, gRPC calls, or shell commands to determine startup status.                                                              |
| [ContainerLogging](documentation/models/ContainerLogging.md)                                                 | Configuration options for directing container logs to a logging provider. This schema enables you to specify a single logging destination for container output, supporting monitoring, debugging, and analytics use cases. Each provider has its own configuration parameters defined in the referenced schemas. Only one logging provider can be selected at a time. |
| [ContainerResourceRequirements](documentation/models/ContainerResourceRequirements.md)                       | Specifies the resource requirements for a container.                                                                                                                                                                                                                                                                                                                  |
| [AxiomLoggingConfiguration](documentation/models/AxiomLoggingConfiguration.md)                               | Configuration settings for integrating container logs with the Axiom logging service. When specified, container logs will be forwarded to the Axiom instance defined by these parameters.                                                                                                                                                                             |
| [DatadogLoggingConfiguration](documentation/models/DatadogLoggingConfiguration.md)                           | Configuration for forwarding container logs to Datadog monitoring service.                                                                                                                                                                                                                                                                                            |
| [ContainerLoggingConfigurationHttp_1](documentation/models/ContainerLoggingConfigurationHttp1.md)            | Configuration for sending container logs to an HTTP endpoint. Defines how logs are formatted, compressed, and transmitted.                                                                                                                                                                                                                                            |
| [NewRelicLoggingConfiguration](documentation/models/NewRelicLoggingConfiguration.md)                         | Configuration for sending container logs to New Relic's log management platform.                                                                                                                                                                                                                                                                                      |
| [ContainerLoggingSplunkConfiguration](documentation/models/ContainerLoggingSplunkConfiguration.md)           | Configuration settings for forwarding container logs to a Splunk instance.                                                                                                                                                                                                                                                                                            |
| [TcpLoggingConfiguration](documentation/models/TcpLoggingConfiguration.md)                                   | Configuration for forwarding container logs to a remote TCP endpoint                                                                                                                                                                                                                                                                                                  |
| [DatadogTagForContainerLogging](documentation/models/DatadogTagForContainerLogging.md)                       | Represents a Datadog tag used for container logging metadata.                                                                                                                                                                                                                                                                                                         |
| [ContainerLoggingHttpFormat](documentation/models/ContainerLoggingHttpFormat.md)                             | The format in which logs will be delivered                                                                                                                                                                                                                                                                                                                            |
| [ContainerLoggingHttpHeader](documentation/models/ContainerLoggingHttpHeader.md)                             | Represents an HTTP header used for container logging configuration.                                                                                                                                                                                                                                                                                                   |
| [ContainerLoggingHttpCompression](documentation/models/ContainerLoggingHttpCompression.md)                   | The compression algorithm to apply to logs before transmission                                                                                                                                                                                                                                                                                                        |
| [ContainerGroupInstanceStatusCount](documentation/models/ContainerGroupInstanceStatusCount.md)               | A summary of container group instances categorized by their current lifecycle status                                                                                                                                                                                                                                                                                  |
| [ContainerGroupStatus](documentation/models/ContainerGroupStatus.md)                                         | Represents the current operational state of a container group within the Salad platform.                                                                                                                                                                                                                                                                              |
| [ContainerGroupProbeExec](documentation/models/ContainerGroupProbeExec.md)                                   | Defines the exec action for a probe in a container group. This is used to execute a command inside a container for health checks.                                                                                                                                                                                                                                     |
| [ContainerGroupGRpcProbe](documentation/models/ContainerGroupGRpcProbe.md)                                   | Configuration for gRPC-based health probes in container groups, used to determine container health status.                                                                                                                                                                                                                                                            |
| [ContainerGroupHttpProbeConfiguration](documentation/models/ContainerGroupHttpProbeConfiguration.md)         | Defines HTTP probe configuration for container health checks within a container group.                                                                                                                                                                                                                                                                                |
| [ContainerGroupTcpProbe](documentation/models/ContainerGroupTcpProbe.md)                                     | Configuration for a TCP probe used to check container health via network connectivity.                                                                                                                                                                                                                                                                                |
| [ContainerGroupProbeHttpHeader](documentation/models/ContainerGroupProbeHttpHeader.md)                       |                                                                                                                                                                                                                                                                                                                                                                       |
| [HttpScheme](documentation/models/HttpScheme.md)                                                             | The protocol scheme used for HTTP probe requests in container health checks.                                                                                                                                                                                                                                                                                          |
| [TheContainerGroupNetworkingLoadBalancer](documentation/models/TheContainerGroupNetworkingLoadBalancer.md)   | The container group networking load balancer.                                                                                                                                                                                                                                                                                                                         |
| [ContainerNetworkingProtocol](documentation/models/ContainerNetworkingProtocol.md)                           | Defines the communication protocol used for network traffic between containers or external systems. Currently supports HTTP protocol for web-based communication.                                                                                                                                                                                                     |
| [ContainerConfiguration](documentation/models/ContainerConfiguration.md)                                     | Configuration for creating a container within a container group. Defines the container image, resource requirements, environment variables, and other settings needed to deploy and run the container.                                                                                                                                                                |
| [CreateContainerGroupNetworking](documentation/models/CreateContainerGroupNetworking.md)                     | Network configuration for container groups specifying connectivity parameters, including authentication, protocol, and timeout settings                                                                                                                                                                                                                               |
| [ContainerConfigurationLogging](documentation/models/ContainerConfigurationLogging.md)                       | Configuration options for directing container logs to a logging provider. This schema enables you to specify a single logging destination for container output, supporting monitoring, debugging, and analytics use cases. Each provider has its own configuration parameters defined in the referenced schemas. Only one logging provider can be selected at a time. |
| [ContainerRegistryAuthentication](documentation/models/ContainerRegistryAuthentication.md)                   | Authentication configuration for various container registry types, including AWS ECR, Docker Hub, GCP GAR, GCP GCR, and basic authentication.                                                                                                                                                                                                                         |
| [ContainerLoggingConfigurationHttp_2](documentation/models/ContainerLoggingConfigurationHttp2.md)            | Configuration for sending container logs to an HTTP endpoint. Defines how logs are formatted, compressed, and transmitted.                                                                                                                                                                                                                                            |
| [ContainerRegistryAuthenticationAwsEcr](documentation/models/ContainerRegistryAuthenticationAwsEcr.md)       | Authentication details for AWS Elastic Container Registry (ECR)                                                                                                                                                                                                                                                                                                       |
| [ContainerRegistryAuthenticationBasic](documentation/models/ContainerRegistryAuthenticationBasic.md)         | Basic username and password authentication for generic container registries                                                                                                                                                                                                                                                                                           |
| [ContainerRegistryAuthenticationDockerHub](documentation/models/ContainerRegistryAuthenticationDockerHub.md) | Authentication details for Docker Hub registry                                                                                                                                                                                                                                                                                                                        |
| [ContainerRegistryAuthenticationGcpGar](documentation/models/ContainerRegistryAuthenticationGcpGar.md)       | Authentication details for Google Artifact Registry (GAR)                                                                                                                                                                                                                                                                                                             |
| [ContainerRegistryAuthenticationGcpGcr](documentation/models/ContainerRegistryAuthenticationGcpGcr.md)       | Authentication details for Google Container Registry (GCR)                                                                                                                                                                                                                                                                                                            |
| [UpdateContainer](documentation/models/UpdateContainer.md)                                                   | Represents an update container object                                                                                                                                                                                                                                                                                                                                 |
| [UpdateContainerGroupNetworking](documentation/models/UpdateContainerGroupNetworking.md)                     | Represents update container group networking parameters                                                                                                                                                                                                                                                                                                               |
| [UpdateContainerLogging](documentation/models/UpdateContainerLogging.md)                                     | Configuration options for directing container logs to a logging provider. This schema enables you to specify a single logging destination for container output, supporting monitoring, debugging, and analytics use cases. Each provider has its own configuration parameters defined in the referenced schemas. Only one logging provider can be selected at a time. |
| [ContainerResourceUpdateSchema](documentation/models/ContainerResourceUpdateSchema.md)                       | Defines the resource specifications that can be modified for a container group, including CPU, memory, GPU classes, and storage allocations.                                                                                                                                                                                                                          |
| [TheContainerGroupInstanceState](documentation/models/TheContainerGroupInstanceState.md)                     | The state of the container group instance                                                                                                                                                                                                                                                                                                                             |
| [WorkloadError](documentation/models/WorkloadError.md)                                                       | Represents a workload error                                                                                                                                                                                                                                                                                                                                           |
| [SystemLog](documentation/models/SystemLog.md)                                                               | Represents a system log                                                                                                                                                                                                                                                                                                                                               |
| [QueueJobEvent](documentation/models/QueueJobEvent.md)                                                       | Represents an event for queue job                                                                                                                                                                                                                                                                                                                                     |
| [ContainerGroupsQuotas](documentation/models/ContainerGroupsQuotas.md)                                       | Represents the organization quotas for container groups                                                                                                                                                                                                                                                                                                               |
| [Status](documentation/models/Status.md)                                                                     | The current status.                                                                                                                                                                                                                                                                                                                                                   |
| [InferenceEndpointJobEvent](documentation/models/InferenceEndpointJobEvent.md)                               | Represents an event for inference endpoint job                                                                                                                                                                                                                                                                                                                        |
| [InferenceEndpointJobEventAction](documentation/models/InferenceEndpointJobEventAction.md)                   | The action that was taken on the inference endpoint job.                                                                                                                                                                                                                                                                                                              |
| [GpuClass](documentation/models/GpuClass.md)                                                                 | Represents a GPU Class                                                                                                                                                                                                                                                                                                                                                |
| [GpuClassPrice](documentation/models/GpuClassPrice.md)                                                       | Represents the price of a GPU class for a given container group priority                                                                                                                                                                                                                                                                                              |

</details>

## License

This SDK is licensed under the MIT License.

See the [LICENSE](LICENSE) file for more details.
